const electron = require('electron');
const storage = require('electron-json-storage');
const app = electron.app;
const BrowserWindow = electron.BrowserWindow;
const ipcMain = electron.ipcMain;
const Menu = electron.Menu;
//const dialog = electron.dialog;

let mainWindow = null;
let optionsWindow = null;
let archiveWindow = null;

const menutemplate = [
    {
        label: 'Меню',
        submenu: [
            {
                label: 'Архив проектов', click()
                {
                    if(archiveWindow !== null) return;
                    archiveWindow = new BrowserWindow({width: 800, height: 600, icon: 'src/img/16x16.png', show: false});
                    archiveWindow.loadURL('file://' + __dirname + '/index.html');
                    archiveWindow.once('ready-to-show', function(){
                        archiveWindow.webContents.send('show-page', 'archive');
                        archiveWindow.show();
                    });
                    //archiveWindow.webContents.openDevTools();
                    archiveWindow.on('closed', function() {
                        archiveWindow = null;
                    });
                }
            },
            {
                label: 'Настройки', click()
                {
                    if(optionsWindow !== null) return;
                    optionsWindow = new BrowserWindow({width: 800, height: 600, icon: 'src/img/16x16.png', show: false});
                    optionsWindow.loadURL('file://' + __dirname + '/index.html');
                    optionsWindow.once('ready-to-show', function(){
                        optionsWindow.webContents.send('show-page', 'options');
                        optionsWindow.show();
                    });
                    //optionsWindow.webContents.openDevTools();
                    optionsWindow.on('closed', function() {
                        optionsWindow = null;
                    });
                }
            }
        ]
    }
];
const menu = Menu.buildFromTemplate(menutemplate);
electron.Menu.setApplicationMenu(menu);

ipcMain.on('loaded', function(event) {
    storage.get('timers', function(error, timers) {
        if (!timers) timers = {};
        event.sender.send('loaded-reply', timers);
    });
});

ipcMain.on('get-options', function(event) {
    storage.get('options', function(error, options) {
        if (!options) options = {};
        event.sender.send('get-options-reply', options);
    });
});

ipcMain.on('delete-project', function(event, ttd) {
    let newTtd = [];
    storage.get('timers', function(error, timers){
        for (i in ttd) {
            if (timers[ttd[i]].archive === false) newTtd.push(ttd[i]);
            delete timers[ttd[i]];
        }
        storage.set('timers', timers, function(er){
            if (!er) status = 'success';
            else status  = er.message;
            event.sender.send('delete-project-reply', status);
            if (mainWindow !== null) mainWindow.webContents.send('delete-project', newTtd);
        });
    });
});

ipcMain.on('save-timer', function(event, data) {
    storage.get('timers', function(error, timers){
        timers[data.id] = data;
        storage.set('timers', timers, function(er){
            if (!er) data['save-status'] = 'success';
            else data['save-status'] = 'error';
            event.sender.send('save-timer-reply', data);
        });
    });
});

ipcMain.on('export-bd', function(event) {
    storage.getAll(function(error, bd){
        event.sender.send('export-bd-reply', bd);
    });
});

ipcMain.on('import-bd', function(event, bd) {
    storage.set('timers', bd.timers, function(er){
        if (er) event.sender.send('import-bd-error');
        if (bd.options) storage.set('options', bd.options);
    });
});

app.on('window-all-closed', function() {
    if (process.platform != 'darwin') {
      app.quit();
    }
});

app.on('ready', function() {
    mainWindow = new BrowserWindow({width: 800, height: 600, icon: 'src/img/16x16.png', show: false});
    mainWindow.loadURL('file://' + __dirname + '/index.html');
    mainWindow.once('ready-to-show', function(){
        mainWindow.webContents.send('show-page', 'index');
        mainWindow.show();
    });
    //mainWindow.webContents.openDevTools();
    mainWindow.on('closed', function() {
        mainWindow = null;
    });
});
